@@ -5,6 +5,7 @@ from .pyorbit_run import *
 from .pyorbit_results import *
 from .model_definitions import *
 from .samplers.pyorbit_emcee import *
+from .samplers.pyorbit_emcee_mpi import *
 from .samplers.pyorbit_zeus import *
 from .samplers.pyorbit_optimize import *
 from .samplers.pyorbit_polychord import *
@@ -13,5 +14,6 @@ from .samplers.pyorbit_nestle import *
 from .samplers.pyorbit_ultranest import *
 from .samplers.pyorbit_multinest import *
 from .samplers.pyorbit_getresults import *
+from .subroutines.input_parser import yaml_parser
 
-__version__ = "9.0.17"
+__version__ = "9.0.19"
