@@ -53,9 +53,9 @@ class Batman_Transit_Eclipse_PhaseCurve(AbstractModel, AbstractTransit):
         self._prepare_planetary_parameters(mc, **kwargs)
         self._prepare_limb_darkening_coefficients(mc, **kwargs)
 
-        if hasattr(kwargs, 'nthreads'):
-            self.code_options['nthreads'] = kwargs['nthreads']
-
+        print('Warning: OpenMP computation on batman temporaroly turned off ')
+        self.code_options['nthreads'] = 1
+        self.batman_params = batman.TransitParams()
 
         if kwargs.get('nightside_emission', True):
             self.nightside_emission = True
@@ -170,8 +170,9 @@ class Batman_Transit_Eclipse_PhaseCurve(AbstractModel, AbstractTransit):
         -> However, we estimated the optimal step size from random parameters, so at some point we'll need to
         reinitialize the model so that the correct step size is computed.
         """
-        if self.code_options['initialization_counter'] > 1000:
-            self.code_options['initialization_counter'] = 0
+        random_selector = np.random.randint(1000)
+
+        if random_selector == 50:
 
             self.batman_eclipse[dataset.name_ref] = batman.TransitModel(self.batman_params,
                                             dataset.x0,
@@ -186,9 +187,6 @@ class Batman_Transit_Eclipse_PhaseCurve(AbstractModel, AbstractTransit):
                                                 exp_time=self.code_options[dataset.name_ref]['exp_time'],
                                                 nthreads=self.code_options['nthreads'])
 
-        else:
-            self.code_options['initialization_counter'] += 1
-
         if x0_input is None:
 
             phase_curve =  amplitude_sin/self.batman_params.fp \
